@@ -1,6 +1,6 @@
 /*
  * Biloba
- * Copyright (C) 2004-2005 Guillaume Demougeot, Colin Leroy
+ * Copyright (C) 2004-2008 Guillaume Demougeot, Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
 
 /**
  * Biloba - Q1 2005
-	* Game by Guillaume Demougeot <dmgt@wanadoo.fr>
-	* Code by Colin Leroy <colin@colino.net>
-	*
-	* i18n stuff
-	*/
+ * Game by Guillaume Demougeot <dmgt@wanadoo.fr>
+ * Code by Colin Leroy <colin@colino.net>
+ *
+ * i18n stuff
+ */
 
 #include <stdlib.h>
 #include <string.h>
@@ -32,47 +32,60 @@
 
 int lang = -1;
 
-static const char *msg[3][11];
+static const char *msg[3][M_NUM_MSGS];
 
+/**
+ * Initialise all messages, in all supported languages
+ */
 void init_msgs(void)
 {
 	msg[0][M_ROUND]="Au tour de ";
 	msg[0][M_DRAW]="Match nul";
-	msg[0][M_WINS]=" vainqueur";
-	msg[0][M_PLAYER_WINS]="Joueur x vainqueur";
+	msg[0][M_WINS]=" remporte la partie !";
+	msg[0][M_PLAYER_WINS]="Joueur xx remporte la partie !";
 	msg[0][M_PLAYER]="Joueur ";
-	msg[0][M_WAITING]="Attente de %d joueur%s";
+	msg[0][M_WAITING]="Attente de %d joueur%s...";
 	msg[0][M_JOINED]="%s nous a rejoint";
 	msg[0][M_NEWGAME]="Nouvelle partie";
 	msg[0][M_ENOCONN]="Connexion impossible";
-	msg[0][M_PLAYER_LEAVES]="Joueur x abandonne";
+	msg[0][M_PLAYER_LEAVES]="Joueur xx abandonne";
 	msg[0][M_LEAVES]=" abandonne";
+	msg[0][M_YOUR_TURN]=" votre tour, ";
 	
 	msg[1][M_ROUND]="Up to ";
 	msg[1][M_DRAW]="Draw";
-	msg[1][M_WINS]=" wins";
-	msg[1][M_PLAYER_WINS]="Player x wins";
+	msg[1][M_WINS]=" wins !";
+	msg[1][M_PLAYER_WINS]="Player xx wins!";
 	msg[1][M_PLAYER]="Player ";
 	msg[1][M_WAITING]="Waiting for %d player%s";
 	msg[1][M_JOINED]="%s joined";
 	msg[1][M_NEWGAME]="New game";
 	msg[1][M_ENOCONN]="Connection failed";
-	msg[1][M_PLAYER_LEAVES]="Player x leaves";
+	msg[1][M_PLAYER_LEAVES]="Player xx leaves";
 	msg[1][M_LEAVES]=" leaves";
-	
+	msg[1][M_YOUR_TURN]="Up to you, ";
+
 	msg[2][M_ROUND]="Turno de ";
 	msg[2][M_DRAW]="Empate";
 	msg[2][M_WINS]=" victorias";
-	msg[2][M_PLAYER_WINS]="El jugador x gana";
+	msg[2][M_PLAYER_WINS]="Jugador xx gana";
 	msg[2][M_PLAYER]="Jugador ";
 	msg[2][M_WAITING]="Esperando por %d jugador%s";
 	msg[2][M_JOINED]="%s se ha unido";
 	msg[2][M_NEWGAME]="Nuevo juego";
 	msg[2][M_ENOCONN]="Fallo al conectar";
-	msg[2][M_PLAYER_LEAVES]="El jugador x abandona";
+	msg[2][M_PLAYER_LEAVES]="Jugador xx abandona";
 	msg[2][M_LEAVES]=" abandona";
+	msg[2][M_YOUR_TURN]="A tu turno, ";
 }
 
+/**
+ * Gets a message
+ *
+ * @param[in] id	The message we want
+ *
+ * @return The corresponding message, in the user's language.
+ */
 const char *get_msg(MsgId id)
 {
 	if (lang < 0) {
